@@ -1,22 +1,25 @@
-import math
 import hmac
+import math
 from time import time
 
-from fastapi import Request, Depends, Header
-from fastapi.exceptions import HTTPException
-from fastapi.exception_handlers import http_exception_handler
-from fsu.interceptor import adimap
-from fsu.error import UniversalLogicError
-import fsu.internal.error_code as E
 import jwt
+from fastapi import Depends, Header, Request
+from fastapi.exception_handlers import http_exception_handler
+from fastapi.exceptions import HTTPException
+
+import fsu.internal.error_code as E
+from fsu.error import UniversalLogicError
+from fsu.interceptor import adimap
+
 
 def generate_sign(secret, ts, data):
     to_be_signed = f"{data}.{ts}"
 
     return hmac.digest(secret.encode(), to_be_signed.encode(), "sha256").hex()
 
+
 def sign_required(get_secret_by_uaid, ttl):
-    async def middleware(request : Request, call_next):
+    async def middleware(request : Request):
         headers = request.headers
 
         if any(k not in headers for k in ["x-uaid", "x-timestamp", "x-signature"]):
@@ -50,9 +53,7 @@ def sign_required(get_secret_by_uaid, ttl):
         if sign != headers["x-signature"]:
             return await http_exception_handler(request, HTTPException(400, "bad signature"))
 
-        return await call_next(request)
-
-    return middleware
+    return adimap(middleware)
 
 
 def get_jwt_info(jwt_secret, invalid_token_error = E.INVALID_TOKEN):
